@@ -4,7 +4,8 @@
 #define _CCCHH_DOORIS_DESKTOP_WIDGET
 
 
-#define WIDGET_NAME "ccchh-dooris-widget"
+#define WIDGET_NAME PACKAGE_STRING
+// #define WIDGET_NAME "ccchh-dooris-widget-"PACKAGE_VERSION
 
 // gconf base path
 #define GCONF_DIR "/apps/maemo/ccchh-dooris-widget"
@@ -45,6 +46,7 @@
 
 G_BEGIN_DECLS
 
+
 #include <libhildondesktop/libhildondesktop.h>
 #include <conic.h> /* libconic - Internet Connectivity library */
 #include <gconf/gconf-client.h>
@@ -85,7 +87,7 @@ typedef struct {
 	gboolean force_banner;
 	gboolean connected;
 	gboolean highlighted;
-	gchar *disconnecting;
+	gchar *disconnecting_iap;
 	gdouble current_alpha;
 	GStaticMutex button_lock;
 	GStaticMutex fetch_lock;
@@ -104,6 +106,7 @@ typedef struct {
 	gboolean notify_enabled;
 	gboolean use_connection;
 	gboolean force_connection;
+	gboolean auto_update;
 
 	// used by the settings dialog
 	GtkWidget *settings_window;
@@ -127,6 +130,16 @@ GType ccchh_dooris_desktop_widget_get_type (void);
 
 CCCHHDoorIsDesktopWidget* ccchh_dooris_desktop_widget_new (void);
 
+
+// invalidate widget region, force expose event
+static void
+force_redraw (CCCHHDoorIsDesktopWidget *self);
+
+// display informational banner
+static void
+show_status_banner (CCCHHDoorIsDesktopWidget *self);
+
+
 // timer callback function
 static gboolean
 ccchh_dooris_desktop_widget_on_timeout (gpointer data);
@@ -136,35 +149,32 @@ static void
 ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 	ConIcConnectionEvent *event, gpointer user_data);
 
-
+// async I/O timeout callback function
 static gboolean
 fetch_update_cancel_cb (gpointer data);
 
+// async I/O open callback function
 static void
 fetch_update_async_open_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	gpointer data);
 
+// async I/O read callback function
 static void
 fetch_update_async_read_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	gpointer buffer, GnomeVFSFileSize bytes_requested, GnomeVFSFileSize bytes_read,
 	gpointer data);
 
+// async I/O close callback function
 static void
 fetch_update_async_close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	gpointer data);
 
-
+// update state with new data
 static void
 fetch_update_process (CCCHHDoorIsDesktopWidget *self, dooris_state_t new_state,
     gulong new_change_ts, gulong new_report_ts);
 
 
-static void
-force_redraw (CCCHHDoorIsDesktopWidget *self);
-
-static void
-show_status_banner (CCCHHDoorIsDesktopWidget *self);
-
 G_END_DECLS
 
 #endif /* _CCCHH_DOORIS_DESKTOP_WIDGET */
